Package: pfwim
Title: Food Web Construction for Paleo Communities
Version: 1.0.2
Authors@R: c(
    person("Tanya", "Strydom", role = c("aut", "cre"), email = "t.strydom@sheffield.ac.uk",
           comment = c(ORCID = "0000-0001-6067-1349")),
    person("Jack O.", "Shaw", role = c("ctb"),
           comment = c(ORCID = "0000-0002-2725-2334")),
    person("Alexander M.", "Dunhill", role = "ctb",
           comment = c(ORCID = "0000-0002-8680-9163")),
    person("Andrew", "Beckerman", role = "ctb",
           comment = c(ORCID = "0000-0002-7859-8394")),
    person("Baran", "Karapunar", role = "ctb",
           comment = c(ORCID = "0000-0001-9711-1492")),
    person("Jennifer A.", "Dunne", role = "ctb",
           comment = c(ORCID = "0000-0002-3789-9561")),
    person("Pincelli M.", "Hull", role = "ctb",
           comment = c(ORCID = "0000-0001-8607-4817"))
  )
Description: R tools for reconstructing paleo food webs from species traits and size rules.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Depends: R (>= 3.5)
LazyData: true
Imports: dplyr, stats, tibble, tidyr, tidyselect
Suggests: igraph, knitr, rmarkdown, testthat (>= 3.0.0)
Config/testthat/edition: 3
VignetteBuilder: knitr
URL: https://beckslab.github.io/pfwim/,
        https://github.com/BecksLab/pfwim
NeedsCompilation: no
Packaged: 2026-04-25 10:15:13 UTC; tanyastrydom
Author: Tanya Strydom [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-6067-1349>),
  Jack O. Shaw [ctb] (ORCID: <https://orcid.org/0000-0002-2725-2334>),
  Alexander M. Dunhill [ctb] (ORCID:
    <https://orcid.org/0000-0002-8680-9163>),
  Andrew Beckerman [ctb] (ORCID: <https://orcid.org/0000-0002-7859-8394>),
  Baran Karapunar [ctb] (ORCID: <https://orcid.org/0000-0001-9711-1492>),
  Jennifer A. Dunne [ctb] (ORCID:
    <https://orcid.org/0000-0002-3789-9561>),
  Pincelli M. Hull [ctb] (ORCID: <https://orcid.org/0000-0001-8607-4817>)
Maintainer: Tanya Strydom <t.strydom@sheffield.ac.uk>
Repository: CRAN
Date/Publication: 2026-04-28 19:30:24 UTC
Built: R 4.5.2; ; 2026-04-28 20:13:25 UTC; unix
