# Generated by roxygen2: do not edit by hand

export(infer_edgelist)
export(powerlaw_prey)
importFrom(dplyr,any_vars)
importFrom(dplyr,bind_rows)
importFrom(dplyr,filter_all)
importFrom(dplyr,sample_n)
importFrom(stats,na.omit)
importFrom(stats,setNames)
importFrom(tidyr,"%>%")
importFrom(tidyselect,all_of)
