#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @importFrom dplyr any_vars
#' @importFrom dplyr bind_rows
#' @importFrom dplyr filter_all
#' @importFrom dplyr sample_n
#' @importFrom stats na.omit
#' @importFrom stats setNames
#' @importFrom tidyr %>%
#' @importFrom tidyselect all_of
## usethis namespace: end
NULL
